.. py:currentmodule:: rubin_scheduler

.. _rubin-scheduler-index:

###############
rubin_scheduler
###############

Scheduling and simulating millions of observations for the Rubin C. Observatory's Legacy Survey of Space and Time (LSST).

.. toctree::
    :maxdepth: 2

    Introduction <introduction>
    Installation <installation>
    User Guide <user-guide>
    API <api>


